@@ -27,7 +27,7 @@ from celery import states
 from celery.app import current_task
 from celery.datastructures import LRUCache
 from celery.exceptions import TimeoutError, TaskRevokedError
-from celery.result import from_serializable
+from celery.result import from_serializable, GroupResult
 from celery.utils import timeutils
 from celery.utils.serialization import (
         get_pickled_exception,
@@ -137,6 +137,8 @@ class BaseBackend(object):
 
     def prepare_value(self, result):
         """Prepare value for storage."""
+        if isinstance(result, GroupResult):
+            return result.serializable()
         return result
 
     def forget(self, task_id):
@@ -414,7 +416,7 @@ class KeyValueStoreBackend(BaseDictBackend):
             if timeout and iterations * interval >= timeout:
                 raise TimeoutError('Operation timed out (%s)' % (timeout, ))
             time.sleep(interval)  # don't busy loop.
-            iterations += 0
+            iterations += 1
 
     def _forget(self, task_id):
         self.delete(self.get_key_for_task(task_id))
