@@ -10,7 +10,7 @@ from celery.datastructures import (
     ConfigurationView,
     DependencyGraph,
 )
-from celery.utils.threads import TIMEOUT_MAX
+from celery.utils.compat import THREAD_TIMEOUT_MAX
 from celery.tests.utils import Case, WhateverIO
 
 
@@ -46,10 +46,8 @@ class test_DictAttribute(Case):
         obj.attr1 = 1
         x = DictAttribute(obj)
         x['attr2'] = 2
-        self.assertDictEqual(dict(x.iteritems()),
-                             dict(attr1=1, attr2=2))
-        self.assertDictEqual(dict(x.items()),
-                             dict(attr1=1, attr2=2))
+        self.assertEqual(x['attr1'], 1)
+        self.assertEqual(x['attr2'], 2)
 
 
 class test_ConfigurationView(Case):
@@ -223,7 +221,7 @@ class test_LRUCache(Case):
             def stop(self):
                 self._is_shutdown.set()
                 self._is_stopped.wait()
-                self.join(TIMEOUT_MAX)
+                self.join(THREAD_TIMEOUT_MAX)
 
         burglar = Burglar(x)
         burglar.start()
