@@ -92,7 +92,7 @@ from celery.utils import text
 from celery.utils import timer2
 from celery.utils.functional import noop
 from celery.utils.log import get_logger
-from celery.utils.timeutils import humanize_seconds
+from celery.utils.timeutils import humanize_seconds, timezone
 
 from . import state
 from .bootsteps import StartStopComponent
@@ -120,7 +120,7 @@ The message has been ignored and discarded.
 
 Did you remember to import the module containing this task?
 Or maybe you are using relative imports?
-Please see http://bit.ly/gLye1c for more information.
+More: http://docs.celeryq.org/en/latest/userguide/tasks.html#names
 
 The full contents of the message body was:
 %s
@@ -131,8 +131,8 @@ INVALID_TASK_ERROR = """\
 Received invalid task message: %s
 The message has been ignored and discarded.
 
-Please ensure your message conforms to the task
-message protocol as described here: http://bit.ly/hYj41y
+Please ensure your message conforms to the task message format:
+http://docs.celeryq.org/en/latest/internals/protocol.html
 
 The full contents of the message body was:
 %s
@@ -516,16 +516,18 @@ class Consumer(object):
                     expires=task.expires and task.expires.isoformat())
 
         if task.eta:
+            eta = timezone.to_system(task.eta) if task.utc else task.eta
             try:
-                eta = timer2.to_timestamp(task.eta)
+                eta = timer2.to_timestamp(eta)
             except OverflowError, exc:
                 error("Couldn't convert eta %s to timestamp: %r. Task: %r",
                       task.eta, exc, task.info(safe=True), exc_info=True)
                 task.acknowledge()
             else:
                 self.qos.increment_eventually()
-                self.timer.apply_at(eta, self.apply_eta_task, (task, ),
-                                    priority=6)
+                self.timer.apply_at(
+                    eta, self.apply_eta_task, (task, ), priority=6,
+                )
         else:
             task_reserved(task)
             self._quick_put(task)
